% Write sensitivity results (ROSA-VSI)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%   H.-X. Zhang, W.P. Dempsey, Jr., and J. Goutsias    %%%%%%%%%%%
%%%%%%%%%%        Probabilistic Sensitivity Analysis of         %%%%%%%%%%%
%%%%%%%%%%            Biochemical Reaction Systems              %%%%%%%%%%%
%%%%%%%%%%  The Journal of Chemical Physics, 131, 094101, 2009  %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%        Reaction-Oriented Sensitivity Analysis        %%%%%%%%%%%
%%%%%%%%%%                   VSI COMPUTATION                    %%%%%%%%%%%
%%%%%%%%%%              Last Modified: 08/11/2009               %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Write response means and variances
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

% TIMING

fid = fopen('..\results\reports\timing_resp.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'RESPONSE MEAN AND VARIANCE RESULTS (TIMING)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of perturbations = %2.4f',rlambda);
fprintf(fid,'\n\n\nReaction\tMEAN\t\tVARIANCE\n');
for m = 1:M
    Sens = [reac(m);meanTT(m);varmTT(m)];
    fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f',Sens);
end
fclose(fid);

% DURATION

fid = fopen('..\results\reports\duration_resp.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'RESPONSE MEAN AND VARIANCE RESULTS (DURATION)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of perturbations = %2.4f',rlambda);
fprintf(fid,'\n\n\nReaction\tMEAN\t\tVARIANCE\n');
for m = 1:M
    Sens = [reac(m);meanDD(m);varmDD(m)];
    fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f',Sens);
end
fclose(fid);

% STRENGTH

fid = fopen('..\results\reports\strength_resp.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'RESPONSE MEAN AND VARIANCE RESULTS (STRENGTH)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of perturbations = %2.4f',rlambda);
fprintf(fid,'\n\n\nReaction\tMEAN\t\tVARIANCE\n');
for m = 1:M
    Sens = [reac(m);meanSS(m);varmSS(m)];
    fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f',Sens);
end
fclose(fid);

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Write SESIs and TESIs
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

% TIMING

fid = fopen('..\results\reports\timing_sens.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED REACTION CLASSIFICATION RESULTS (TIMING)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of perturbations = %2.4f',rlambda);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\ndelta = %2.4f',deltat);
fprintf(fid,'\n\ngamma = %2.4f',gammat);
fprintf(fid,'\n\n\nReaction\tTESI\t\tSESI\t\tJESI\t\tClassification\n');
for m = 1:M
    Sens = [reac(m);taut(m);sigmat(m);etat(m)];
    if sigmat(m) <= theta && etat(m) <= theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\tNON-INFLUENTIAL',Sens);
    end
    if sigmat(m) > theta && etat(m) <= theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (singularly)',Sens);
    end
    if sigmat(m) <= theta && etat(m) > theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (jointly)',Sens);
    end
    if sigmat(m) > theta && etat(m) > theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (singularly & jointly)',Sens);
    end
end
fprintf(fid,'\n\nNOTES: delta = 0 implies no joint perturbation effects');
fprintf(fid,'\n       gamma = 0 implies no joint perturbation effects of order > 2');
fclose(fid);

% DURATION

fid = fopen('..\results\reports\duration_sens.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED REACTION CLASSIFICATION RESULTS (DURATION)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of perturbations = %2.4f',rlambda);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\ndelta = %2.4f',deltad);
fprintf(fid,'\n\ngamma = %2.4f',gammad);
fprintf(fid,'\n\n\nReaction\tTESI\t\tSESI\t\tJESI\t\tClassification\n');
for m = 1:M
    Sens = [reac(m);taud(m);sigmad(m);etad(m)];
    if sigmad(m) <= theta && etad(m) <= theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\tNON-INFLUENTIAL',Sens);
    end
    if sigmad(m) > theta && etad(m) <= theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (singularly)',Sens);
    end
    if sigmad(m) <= theta && etad(m) > theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (jointly)',Sens);
    end
    if sigmad(m) > theta && etad(m) > theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (singularly & jointly)',Sens);
    end
end
fprintf(fid,'\n\nNOTES: delta = 0 implies no joint perturbation effects');
fprintf(fid,'\n       gamma = 0 implies no joint perturbation effects of order > 2');
fclose(fid);

% STRENGTH

fid = fopen('..\results\reports\strength_sens.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED REACTION CLASSIFICATION RESULTS (STRENGTH)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of perturbations = %2.4f',rlambda);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\ndelta = %2.4f',deltas);
fprintf(fid,'\n\ngamma = %2.4f',gammas);
fprintf(fid,'\n\n\nReaction\tTESI\t\tSESI\t\tJESI\t\tClassification\n');
for m = 1:M
    Sens = [reac(m);taus(m);sigmas(m);etas(m)];
    if sigmas(m) <= theta && etas(m) <= theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\tNON-INFLUENTIAL',Sens);
    end
    if sigmas(m) > theta && etas(m) <= theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (singularly)',Sens);
    end
    if sigmas(m) <= theta && etas(m) > theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (jointly)',Sens);
    end
    if sigmas(m) > theta && etas(m) > theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (singularly & jointly)',Sens);
    end
end
fprintf(fid,'\n\nNOTES: delta = 0 implies no joint perturbation effects');
fprintf(fid,'\n       gamma = 0 implies no joint perturbation effects of order > 2');
fclose(fid);

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Write singular reaction ranking results
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

% TIMING

fid = fopen('..\results\reports\timing_rank_singular.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED SINGULAR REACTION RANKING RESULTS (TIMING)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of perturbations = %2.4f',rlambda);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\ndelta = %2.4f',deltat);
fprintf(fid,'\n\ngamma = %2.4f',gammat);
fprintf(fid,'\n\n\nReaction\t\tSESI\t\t\tClassification\n');
for m = 1:M
    Sens = [IT(M-m+1);sigmat(IT(M-m+1))];
    if sigmat(IT(M-m+1)) > theta && etat(IT(M-m+1)) <= theta
        fprintf(fid,'\n%1.0f\t%18.4f\t\t\tINFLUENTIAL (singularly)',Sens);
    end
    if sigmat(IT(M-m+1)) <= theta && etat(IT(M-m+1)) > theta
        fprintf(fid,'\n%1.0f\t%18.4f\t\t\tINFLUENTIAL (jointly)',Sens);
    end
    if sigmat(IT(M-m+1)) > theta && etat(IT(M-m+1)) > theta
        fprintf(fid,'\n%1.0f\t%18.4f\t\t\tINFLUENTIAL (singularly & jointly)',Sens);
    end
end
fprintf(fid,'\n\nNOTES: delta = 0 implies no joint perturbation effects');
fprintf(fid,'\n       gamma = 0 implies no joint perturbation effects of order > 2');
fclose(fid);

% DURATION

fid = fopen('..\results\reports\duration_rank_singular.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED SINGULAR REACTION RANKING RESULTS (DURATION)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of perturbations = %2.4f',rlambda);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\ndelta = %2.4f',deltad);
fprintf(fid,'\n\ngamma = %2.4f',gammad);
fprintf(fid,'\n\n\nReaction\t\tSESI\t\t\tClassification\n');
for m = 1:M
    Sens = [ID(M-m+1);sigmad(ID(M-m+1))];
    if sigmad(ID(M-m+1)) > theta && etad(ID(M-m+1)) <= theta
        fprintf(fid,'\n%1.0f\t%18.4f\t\t\tINFLUENTIAL (singularly)',Sens);
    end
    if sigmad(ID(M-m+1)) <= theta && etad(ID(M-m+1)) > theta
        fprintf(fid,'\n%1.0f\t%18.4f\t\t\tINFLUENTIAL (jointly)',Sens);
    end
    if sigmad(ID(M-m+1)) > theta && etad(ID(M-m+1)) > theta
        fprintf(fid,'\n%1.0f\t%18.4f\t\t\tINFLUENTIAL (singularly & jointly)',Sens);
    end
end
fprintf(fid,'\n\nNOTES: delta = 0 implies no joint perturbation effects');
fprintf(fid,'\n       gamma = 0 implies no joint perturbation effects of order > 2');
fclose(fid);

% STRENGTH

fid = fopen('..\results\reports\strength_rank_singular.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED SINGULAR REACTION RANKING RESULTS (STRENGTH)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of perturbations = %2.4f',rlambda);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\ndelta = %2.4f',deltas);
fprintf(fid,'\n\ngamma = %2.4f',gammas);
fprintf(fid,'\n\n\nReaction\t\tSESI\t\t\tClassification\n');
for m = 1:M
    Sens = [IS(M-m+1);sigmas(IS(M-m+1))];
    if sigmas(IS(M-m+1)) > theta && etas(IS(M-m+1)) <= theta
        fprintf(fid,'\n%1.0f\t%18.4f\t\t\tINFLUENTIAL (singularly)',Sens);
    end
    if sigmas(IS(M-m+1)) <= theta && etas(IS(M-m+1)) > theta
        fprintf(fid,'\n%1.0f\t%18.4f\t\t\tINFLUENTIAL (jointly)',Sens);
    end
    if sigmas(IS(M-m+1)) > theta && etas(IS(M-m+1)) > theta
        fprintf(fid,'\n%1.0f\t%18.4f\t\t\tINFLUENTIAL (singularly & jointly)',Sens);
    end
end
fprintf(fid,'\n\nNOTES: delta = 0 implies no joint perturbation effects');
fprintf(fid,'\n       gamma = 0 implies no joint perturbation effects of order > 2');
fclose(fid);

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Write PESI's
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

% TIMING

fid = fopen('..\results\reports\timing_pesi.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED PESI (TIMING)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of perturbations = %2.4f',rlambda);
fprintf(fid,'\n\nThreshold = %2.4f\n',theta);
for m = 1:M
    if sigmat(IT(M-m+1)) <= theta && etat(IT(M-m+1)) > theta
        fprintf(fid,'\n\nINFLUENTIAL (jointly)\n');
        fprintf(fid,'-------------------------');
        for n = 1:M
            nut(n,n) = 0;
            if nut(IT(M-m+1),n) > 0
                fprintf(fid,'\n(%1.0f-%2.0f)%8.4f',IT(M-m+1),n,nut(IT(M-m+1),n));
            end
        end
    end
   if sigmat(IT(M-m+1)) > theta && etat(IT(M-m+1)) > theta
        fprintf(fid,'\n\nINFLUENTIAL (singularly & jointly)\n');
        fprintf(fid,'---------------------------------------');
        for n = 1:M
            nut(n,n) = 0;
            if nut(IT(M-m+1),n) > 0
                fprintf(fid,'\n(%1.0f-%2.0f)%8.4f',IT(M-m+1),n,nut(IT(M-m+1),n));
            end
        end
    end
end
fclose(fid);

% DURATION

fid = fopen('..\results\reports\duration_pesi.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED PESI (DURATION)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of perturbations = %2.4f',rlambda);
fprintf(fid,'\n\nThreshold = %2.4f\n',theta);
for m = 1:M
    if sigmad(ID(M-m+1)) <= theta && etad(ID(M-m+1)) > theta
        fprintf(fid,'\n\nINFLUENTIAL (jointly)\n');
        fprintf(fid,'-------------------------');
        for n = 1:M
            nud(n,n) = 0;
            if nud(ID(M-m+1),n) > 0
                fprintf(fid,'\n(%1.0f-%2.0f)%8.4f',ID(M-m+1),n,nud(ID(M-m+1),n));
            end
        end
    end
   if sigmad(ID(M-m+1)) > theta && etad(ID(M-m+1)) > theta
        fprintf(fid,'\n\nINFLUENTIAL (singularly & jointly)\n');
        fprintf(fid,'---------------------------------------');
        for n = 1:M
            nud(n,n) = 0;
            if nud(ID(M-m+1),n) > 0
                fprintf(fid,'\n(%1.0f-%2.0f)%8.4f',ID(M-m+1),n,nud(ID(M-m+1),n));
            end
        end
    end
end
fclose(fid);

% STRENGTH

fid = fopen('..\results\reports\strength_pesi.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED PESI (STRENGTH)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of perturbations = %2.4f',rlambda);
fprintf(fid,'\n\nThreshold = %2.4f\n',theta);
for m = 1:M
    if sigmas(IS(M-m+1)) <= theta && etas(IS(M-m+1)) > theta
        fprintf(fid,'\n\nINFLUENTIAL (jointly)\n');
        fprintf(fid,'-------------------------');
        for n = 1:M
            nus(n,n) = 0;
            if nus(IS(M-m+1),n) > 0
                fprintf(fid,'\n(%1.0f-%2.0f)%8.4f',IS(M-m+1),n,nus(IS(M-m+1),n));
            end
        end
    end
   if sigmas(IS(M-m+1)) > theta && etas(IS(M-m+1)) > theta
        fprintf(fid,'\n\nINFLUENTIAL (singularly & jointly)\n');
        fprintf(fid,'---------------------------------------');
        for n = 1:M
            nus(n,n) = 0;
            if nus(IS(M-m+1),n) > 0
                fprintf(fid,'\n(%1.0f-%2.0f)%8.4f',IS(M-m+1),n,nus(IS(M-m+1),n));
            end
        end
    end
end
fclose(fid);

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Write joint reaction ranking results
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

% TIMING

fid = fopen('..\results\reports\timing_rank_joint.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED JOINT REACTION RANKING RESULTS (TIMING)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of perturbations = %2.4f',rlambda);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\ndelta = %2.4f',deltat);
fprintf(fid,'\n\ngamma = %2.4f',gammat);
fprintf(fid,'\n\n\nReactions\t\tDESI\n');
for m = 1:M*M
    reac1 = floor((I2T(M*M-m+1)-1)/M)+1;
    reac2 = I2T(M*M-m+1)-(reac1-1)*M;
    if vsigma2t(I2T(M*M-m+1)) > theta
        fprintf(fid,'\n(%1.0f-%1.0f)\t%14.4f',reac1,reac2,vsigma2t(I2T(M*M-m+1)));
    end
end
fprintf(fid,'\n\nNOTES: delta = 0 implies no joint perturbation effects');
fprintf(fid,'\n       gamma = 0 implies no joint perturbation effects of order > 2');
fclose(fid);

% DURATION

fid = fopen('..\results\reports\duration_rank_joint.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED JOINT REACTION RANKING RESULTS (DURATION)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of perturbations = %2.4f',rlambda);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\ndelta = %2.4f',deltad);
fprintf(fid,'\n\ngamma = %2.4f',gammad);
fprintf(fid,'\n\n\nReactions\t\tDESI\n');
for m = 1:M*M
    reac1 = floor((I2D(M*M-m+1)-1)/M)+1;
    reac2 = I2D(M*M-m+1)-(reac1-1)*M;
    if vsigma2d(I2D(M*M-m+1)) > theta
        fprintf(fid,'\n(%1.0f-%1.0f)\t%14.4f',reac1,reac2,vsigma2d(I2D(M*M-m+1)));
    end
end
fprintf(fid,'\n\nNOTES: delta = 0 implies no joint perturbation effects');
fprintf(fid,'\n       gamma = 0 implies no joint perturbation effects of order > 2');
fclose(fid);

% STRENGTH

fid = fopen('..\results\reports\strength_rank_joint.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED JOINT REACTION RANKING RESULTS (STRENGTH)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of perturbations = %2.4f',rlambda);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\ndelta = %2.4f',deltas);
fprintf(fid,'\n\ngamma = %2.4f',gammas);
fprintf(fid,'\n\n\nReactions\t\tDESI\n');
for m = 1:M*M
    reac1 = floor((I2S(M*M-m+1)-1)/M)+1;
    reac2 = I2S(M*M-m+1)-(reac1-1)*M;
    if vsigma2s(I2S(M*M-m+1)) > theta
        fprintf(fid,'\n(%1.0f-%1.0f)\t%14.4f',reac1,reac2,vsigma2s(I2S(M*M-m+1)));
    end
end
fprintf(fid,'\n\nNOTES: delta = 0 implies no joint perturbation effects');
fprintf(fid,'\n       gamma = 0 implies no joint perturbation effects of order > 2');
fclose(fid);