% Response features (ROSOSA-VSI)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%   H.-X. Zhang, W.P. Dempsey, Jr., and J. Goutsias    %%%%%%%%%%%
%%%%%%%%%%        Probabilistic Sensitivity Analysis of         %%%%%%%%%%%
%%%%%%%%%%            Biochemical Reaction Systems              %%%%%%%%%%%
%%%%%%%%%%  The Journal of Chemical Physics, 131, 094101, 2009  %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%  Reaction and Species-Oriented Sensitivity Analysis  %%%%%%%%%%%
%%%%%%%%%%                   VSI COMPUTATION                    %%%%%%%%%%%
%%%%%%%%%%              Last Modified: 08/11/2009               %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

function[TIM,DUR,STR] = featureit(species,q,t,tresol,durtol)

% TIM:     timing
% DUR:     duration
% STR:     strength
% species: molecular species of interest (1,2,...,N)
% q:       molecular activities

response = q(:,species);
tmax     = length(t);

cumsum_response = cumsum(response);
med_locat       = find(cumsum_response >= (0.5*cumsum_response(tmax)));
trans_locat     = find(cumsum_response >= ((1-durtol)*cumsum_response(tmax)));

TIM = 60*tresol*(min(med_locat)-1);
DUR = 60*tresol*(min(trans_locat)-1);

STR = 0;
if DUR > 0
    STR = trapz(t,response)/DUR;
end

TIM = log(1+(TIM-1)*(TIM>0)); 
DUR = log(1+(DUR-1)*(DUR>0));
STR = log(1+(STR-1)*(STR>0));