% Variance-based sensitivity indices (SOSA-VSI)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%   H.-X. Zhang, W.P. Dempsey, Jr., and J. Goutsias    %%%%%%%%%%%
%%%%%%%%%%        Probabilistic Sensitivity Analysis of         %%%%%%%%%%%
%%%%%%%%%%            Biochemical Reaction Systems              %%%%%%%%%%%
%%%%%%%%%%  The Journal of Chemical Physics, 131, 094101, 2009  %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%         Species-Oriented Sensitivity Analysis        %%%%%%%%%%%
%%%%%%%%%%                   VSI COMPUTATION                    %%%%%%%%%%%
%%%%%%%%%%              Last Modified: 08/11/2009               %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% First-order calculations
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

% Calculate SESIs

sigmat = varfTT./varmTT;
sigmad = varfDD./varmDD;
sigmas = varfSS./varmSS;

% Calculate TESIs 

taut = 1 - varvTT./varmTT;
taud = 1 - varvDD./varmDD;
taus = 1 - varvSS./varmSS;

% Calculate JESIs

etat = taut - sigmat;
etad = taud - sigmad;
etas = taus - sigmas;

% Calculate delta

deltat = 1 - sum(sigmat);
deltad = 1 - sum(sigmad);
deltas = 1 - sum(sigmas);

deltat = deltat*(deltat > 0);
deltad = deltad*(deltad > 0);
deltas = deltas*(deltas > 0);

% Sort SESI values

[ssigmat,IT] = sort(sigmat);
[ssigmad,ID] = sort(sigmad);
[ssigmas,IS] = sort(sigmas);

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Second-order calculations
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

% Calculate DESIs

sigma2t = var2fTT./varmmTT;
sigma2d = var2fDD./varmmDD;
sigma2s = var2fSS./varmmSS;

% Sort DESI values

for n = 1:N
    for m = 1:n
        sigma2t(n,m) = 0;   % set diagonal and lower left side of matrix to
        sigma2d(n,m) = 0;   % zero to avoid redundancy in sorting due 
        sigma2s(n,m) = 0;   % to symmetry
    end
end
        
for n = 1:N
   vsigma2t((n-1)*N+1:n*N) = sigma2t(n,:);
   vsigma2d((n-1)*N+1:n*N) = sigma2d(n,:);
   vsigma2s((n-1)*N+1:n*N) = sigma2s(n,:);
end

[svsigma2t,I2T] = sort(vsigma2t);
[svsigma2d,I2D] = sort(vsigma2d);
[svsigma2s,I2S] = sort(vsigma2s);

% Calculate PESIs

for n = 1:N
    nut(n,1:N) = sigma2t(n,1:N) - sigmat(n) - sigmat(1:N);
    nud(n,1:N) = sigma2d(n,1:N) - sigmad(n) - sigmad(1:N);
    nus(n,1:N) = sigma2s(n,1:N) - sigmas(n) - sigmas(1:N);
end

nut = nut.*(nut > 0);
nud = nud.*(nud > 0);
nus = nus.*(nus > 0);

% Calculate gamma

gammat = 1 - sum(sigmat) - sum(sum(nut));
gammad = 1 - sum(sigmad) - sum(sum(nud));
gammas = 1 - sum(sigmas) - sum(sum(nus));

gammat = gammat*(gammat > 0);
gammad = gammad*(gammad > 0);
gammas = gammas*(gammas > 0);