% Write sensitivity results (SOSA-VSI)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%   H.-X. Zhang, W.P. Dempsey, Jr., and J. Goutsias    %%%%%%%%%%%
%%%%%%%%%%        Probabilistic Sensitivity Analysis of         %%%%%%%%%%%
%%%%%%%%%%            Biochemical Reaction Systems              %%%%%%%%%%%
%%%%%%%%%%  The Journal of Chemical Physics, 131, 094101, 2009  %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%         Species-Oriented Sensitivity Analysis        %%%%%%%%%%%
%%%%%%%%%%                   VSI COMPUTATION                    %%%%%%%%%%%
%%%%%%%%%%              Last Modified: 08/11/2009               %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Write response means and variances
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

% TIMING

fid = fopen('..\results\reports\timing_resp.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'RESPONSE MEAN AND VARIANCE RESULTS (TIMING)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of perturbations = %2.4f',slambda);
fprintf(fid,'\n\n\nSpecies\t\tMEAN\t\tVARIANCE\n');
for n = 1:N
    Sens = [spec(n);meanTT(n);varmTT(n)];
    fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f',Sens);
end
fclose(fid);

% DURATION

fid = fopen('..\results\reports\duration_resp.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'RESPONSE MEAN AND VARIANCE RESULTS (DURATION)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of perturbations = %2.4f',slambda);
fprintf(fid,'\n\n\nSpecies\t\tMEAN\t\tVARIANCE\n');
for n = 1:N
    Sens = [spec(n);meanDD(n);varmDD(n)];
    fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f',Sens);
end
fclose(fid);

% STRENGTH

fid = fopen('..\results\reports\strength_resp.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'RESPONSE MEAN AND VARIANCE RESULTS (STRENGTH)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of perturbations = %2.4f',slambda);
fprintf(fid,'\n\n\nSpecies\t\tMEAN\t\tVARIANCE\n');
for n = 1:N
    Sens = [spec(n);meanSS(n);varmSS(n)];
    fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f',Sens);
end
fclose(fid);

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Write SESIs and TESIs
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

fid = fopen('..\results\reports\timing_sens.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED SPECIES CLASSIFICATION RESULTS (TIMING)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of perturbations = %2.4f',slambda);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\ndelta = %2.4f',deltat);
fprintf(fid,'\n\ngamma = %2.4f',gammat);
fprintf(fid,'\n\n\nSpecies\t\tTESI\t\tSESI\t\tJESI\t\tClassification\n');
for n = 1:N
    Sens = [spec(n);taut(n);sigmat(n);etat(n)];
    if sigmat(n) <= theta && etat(n) <= theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\tNON-INFLUENTIAL',Sens);
    end
    if sigmat(n) > theta && etat(n) <= theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (singularly)',Sens);
    end
    if sigmat(n) <= theta && etat(n) > theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (jointly)',Sens);
    end
    if sigmat(n) > theta && etat(n) > theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (singularly & jointly)',Sens);
    end
end
fprintf(fid,'\n\nNOTES: delta = 0 implies no joint perturbation effects');
fprintf(fid,'\n       gamma = 0 implies no joint perturbation effects of order > 2');
fclose(fid);

% DURATION

fid = fopen('..\results\reports\duration_sens.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED SPECIES CLASSIFICATION RESULTS (DURATION)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of perturbations = %2.4f',slambda);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\ndelta = %2.4f',deltad);
fprintf(fid,'\n\ngamma = %2.4f',gammad);
fprintf(fid,'\n\n\nSpecies\t\tTESI\t\tSESI\t\tJESI\t\tClassification\n');
for n = 1:N
    Sens = [spec(n);taud(n);sigmad(n);etad(n)];
    if sigmad(n) <= theta && etad(n) <= theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\tNON-INFLUENTIAL',Sens);
    end
    if sigmad(n) > theta && etad(n) <= theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (singularly)',Sens);
    end
    if sigmad(n) <= theta && etad(n) > theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (jointly)',Sens);
    end
    if sigmad(n) > theta && etad(n) > theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (singularly & jointly)',Sens);
    end
end
fprintf(fid,'\n\nNOTES: delta = 0 implies no joint perturbation effects');
fprintf(fid,'\n       gamma = 0 implies no joint perturbation effects of order > 2');
fclose(fid);

% STRENGTH

fid = fopen('..\results\reports\strength_sens.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED SPECIES CLASSIFICATION RESULTS (STRENGTH)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of perturbations = %2.4f',slambda);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\ndelta = %2.4f',deltas);
fprintf(fid,'\n\ngamma = %2.4f',gammas);
fprintf(fid,'\n\n\nSpecies\t\tTESI\t\tSESI\t\tJESI\t\tClassification\n');
for n = 1:N
    Sens = [spec(n);taus(n);sigmas(n);etas(n)];
    if sigmas(n) <= theta && etas(n) <= theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\tNON-INFLUENTIAL',Sens);
    end
    if sigmas(n) > theta && etas(n) <= theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (singularly)',Sens);
    end
    if sigmas(n) <= theta && etas(n) > theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (jointly)',Sens);
    end
    if sigmas(n) > theta && etas(n) > theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (singularly & jointly)',Sens);
    end
end
fprintf(fid,'\n\nNOTES: delta = 0 implies no joint perturbation effects');
fprintf(fid,'\n       gamma = 0 implies no joint perturbation effects of order > 2');
fclose(fid);

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Write singular species ranking results
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

% TIMING

fid = fopen('..\results\reports\timing_rank_singular.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED SINGULAR SPECIES RANKING RESULTS (TIMING)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of perturbations = %2.4f',slambda);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\ndelta = %2.4f',deltat);
fprintf(fid,'\n\ngamma = %2.4f',gammat);
fprintf(fid,'\n\n\nSpecies\t\t\tSESI\t\t\tClassification\n');
for n = 1:N
    Sens = [IT(N-n+1);sigmat(IT(N-n+1))];
    if sigmat(IT(N-n+1)) > theta && etat(IT(N-n+1)) <= theta
        fprintf(fid,'\n%1.0f\t%18.4f\t\t\tINFLUENTIAL (singularly)',Sens);
    end
    if sigmat(IT(N-n+1)) <= theta && etat(IT(N-n+1)) > theta
        fprintf(fid,'\n%1.0f\t%18.4f\t\t\tINFLUENTIAL (jointly)',Sens);
    end
    if sigmat(IT(N-n+1)) > theta && etat(IT(N-n+1)) > theta
        fprintf(fid,'\n%1.0f\t%18.4f\t\t\tINFLUENTIAL (singularly & jointly)',Sens);
    end
end
fprintf(fid,'\n\nNOTES: delta = 0 implies no joint perturbation effects');
fprintf(fid,'\n       gamma = 0 implies no joint perturbation effects of order > 2');
fclose(fid);

% DURATION

fid = fopen('..\results\reports\duration_rank_singular.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED SINGULAR SPECIES RANKING RESULTS (DURATION)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of perturbations = %2.4f',slambda);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\ndelta = %2.4f',deltad);
fprintf(fid,'\n\ngamma = %2.4f',gammad);
fprintf(fid,'\n\n\nSpecies\t\t\tSESI\t\t\tClassification\n');
for n = 1:N
    Sens = [ID(N-n+1);sigmad(ID(N-n+1))];
    if sigmad(ID(N-n+1)) > theta && etad(ID(N-n+1)) <= theta
        fprintf(fid,'\n%1.0f\t%18.4f\t\t\tINFLUENTIAL (singularly)',Sens);
    end
    if sigmad(ID(N-n+1)) <= theta && etad(ID(N-n+1)) > theta
        fprintf(fid,'\n%1.0f\t%18.4f\t\t\tINFLUENTIAL (jointly)',Sens);
    end
    if sigmad(ID(N-n+1)) > theta && etad(ID(N-n+1)) > theta
        fprintf(fid,'\n%1.0f\t%18.4f\t\t\tINFLUENTIAL (singularly & jointly)',Sens);
    end
end
fprintf(fid,'\n\nNOTES: delta = 0 implies no joint perturbation effects');
fprintf(fid,'\n       gamma = 0 implies no joint perturbation effects of order > 2');
fclose(fid);

% STRENGTH

fid = fopen('..\results\reports\strength_rank_singular.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED SINGULAR SPECIES RANKING RESULTS (STRENGTH)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of perturbations = %2.4f',slambda);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\ndelta = %2.4f',deltas);
fprintf(fid,'\n\ngamma = %2.4f',gammas);
fprintf(fid,'\n\n\nSpecies\t\t\tSESI\t\t\tClassification\n');
for n = 1:N
    Sens = [IS(N-n+1);sigmas(IS(N-n+1))];
    if sigmas(IS(N-n+1)) > theta && etas(IS(N-n+1)) <= theta
        fprintf(fid,'\n%1.0f\t%18.4f\t\t\tINFLUENTIAL (singularly)',Sens);
    end
    if sigmas(IS(N-n+1)) <= theta && etas(IS(N-n+1)) > theta
        fprintf(fid,'\n%1.0f\t%18.4f\t\t\tINFLUENTIAL (jointly)',Sens);
    end
    if sigmas(IS(N-n+1)) > theta && etas(IS(N-n+1)) > theta
        fprintf(fid,'\n%1.0f\t%18.4f\t\t\tINFLUENTIAL (singularly & jointly)',Sens);
    end
end
fprintf(fid,'\n\nNOTES: delta = 0 implies no joint perturbation effects');
fprintf(fid,'\n       gamma = 0 implies no joint perturbation effects of order > 2');
fclose(fid);

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Write PESI's
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

% TIMING

fid = fopen('..\results\reports\timing_pesi.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED PESI (TIMING)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of perturbations = %2.4f',slambda);
fprintf(fid,'\n\nThreshold = %2.4f\n',theta);
for n = 1:N
    if sigmat(IT(N-n+1)) <= theta && etat(IT(N-n+1)) > theta
        fprintf(fid,'\n\nINFLUENTIAL (jointly)\n');
        fprintf(fid,'-------------------------');
        for m = 1:N
            nut(m,m) = 0;
            if nut(IT(N-n+1),m) > 0
                fprintf(fid,'\n(%1.0f-%2.0f)%8.4f',IT(N-n+1),m,nut(IT(N-n+1),m));
            end
        end
    end
   if sigmat(IT(N-n+1)) > theta && etat(IT(N-n+1)) > theta
        fprintf(fid,'\n\nINFLUENTIAL (singularly & jointly)\n');
        fprintf(fid,'---------------------------------------');
        for m = 1:N
            nut(m,m) = 0;
            if nut(IT(N-n+1),m) > 0
                fprintf(fid,'\n(%1.0f-%2.0f)%8.4f',IT(N-n+1),m,nut(IT(N-n+1),m));
            end
        end
    end
end
fclose(fid);

% DURATION

fid = fopen('..\results\reports\duration_pesi.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED PESI (DURATION)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of perturbations = %2.4f',slambda);
fprintf(fid,'\n\nThreshold = %2.4f\n',theta);
for n = 1:N
    if sigmad(ID(N-n+1)) <= theta && etad(ID(N-n+1)) > theta
        fprintf(fid,'\n\nINFLUENTIAL (jointly)\n');
        fprintf(fid,'-------------------------');
        for m = 1:N
            nud(m,m) = 0;
            if nud(ID(N-n+1),m) > 0
                fprintf(fid,'\n(%1.0f-%2.0f)%8.4f',ID(N-n+1),m,nud(ID(N-n+1),m));
            end
        end
    end
   if sigmad(ID(N-n+1)) > theta && etad(ID(N-n+1)) > theta
        fprintf(fid,'\n\nINFLUENTIAL (singularly & jointly)\n');
        fprintf(fid,'---------------------------------------');
        for m = 1:N
            nud(m,m) = 0;
            if nud(ID(N-n+1),m) > 0
                fprintf(fid,'\n(%1.0f-%2.0f)%8.4f',ID(N-n+1),m,nud(ID(N-n+1),m));
            end
        end
    end
end
fclose(fid);

% STRENGTH

fid = fopen('..\results\reports\strength_pesi.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED PESI (STRENGTH)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of perturbations = %2.4f',slambda);
fprintf(fid,'\n\nThreshold = %2.4f\n',theta);
for n = 1:N
    if sigmas(IS(N-n+1)) <= theta && etas(IS(N-n+1)) > theta
        fprintf(fid,'\n\nINFLUENTIAL (jointly)\n');
        fprintf(fid,'-------------------------');
        for m = 1:N
            nus(m,m) = 0;
            if nus(IS(N-n+1),m) > 0
                fprintf(fid,'\n(%1.0f-%2.0f)%8.4f',IS(N-n+1),m,nus(IS(N-n+1),m));
            end
        end
    end
   if sigmas(IS(N-n+1)) > theta && etas(IS(N-n+1)) > theta
        fprintf(fid,'\n\nINFLUENTIAL (singularly & jointly)\n');
        fprintf(fid,'---------------------------------------');
        for m = 1:N
            nus(m,m) = 0;
            if nus(IS(N-n+1),m) > 0
                fprintf(fid,'\n(%1.0f-%2.0f)%8.4f',IS(N-n+1),m,nus(IS(N-n+1),m));
            end
        end
    end
end
fclose(fid);

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Write joint species ranking results
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

% TIMING

fid = fopen('..\results\reports\timing_rank_joint.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED JOINT SPECIES RANKING RESULTS (TIMING)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of perturbations = %2.4f',slambda);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\ndelta = %2.4f',deltat);
fprintf(fid,'\n\ngamma = %2.4f',gammat);
fprintf(fid,'\n\n\nSpecies\t\t\tDESI\n');
for n = 1:N*N
    reac1 = floor((I2T(N*N-n+1)-1)/N)+1;
    reac2 = I2T(N*N-n+1)-(reac1-1)*N;
    if vsigma2t(I2T(N*N-n+1)) > theta
        fprintf(fid,'\n(%1.0f-%1.0f)\t%14.4f',reac1,reac2,vsigma2t(I2T(N*N-n+1)));
    end
end
fprintf(fid,'\n\nNOTES: delta = 0 implies no joint perturbation effects');
fprintf(fid,'\n       gamma = 0 implies no joint perturbation effects of order > 2');
fclose(fid);

% DURATION

fid = fopen('..\results\reports\duration_rank_joint.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED JOINT SPECIES RANKING RESULTS (DURATION)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of perturbations = %2.4f',slambda);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\ndelta = %2.4f',deltad);
fprintf(fid,'\n\ngamma = %2.4f',gammad);
fprintf(fid,'\n\n\nSpecies\t\t\tDESI\n');
for n = 1:N*N
    reac1 = floor((I2D(N*N-n+1)-1)/N)+1;
    reac2 = I2D(N*N-n+1)-(reac1-1)*N;
    if vsigma2d(I2D(N*N-n+1)) > theta
        fprintf(fid,'\n(%1.0f-%1.0f)\t%14.4f',reac1,reac2,vsigma2d(I2D(N*N-n+1)));
    end
end
fprintf(fid,'\n\nNOTES: delta = 0 implies no joint perturbation effects');
fprintf(fid,'\n       gamma = 0 implies no joint perturbation effects of order > 2');
fclose(fid);

% STRENGTH

fid = fopen('..\results\reports\strength_rank_joint.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED JOINT SPECIES RANKING RESULTS (STRENGTH)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of perturbations = %2.4f',slambda);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\ndelta = %2.4f',deltas);
fprintf(fid,'\n\ngamma = %2.4f',gammas);
fprintf(fid,'\n\n\nSpecies\t\t\tDESI\n');
for n = 1:N*N
    reac1 = floor((I2S(N*N-n+1)-1)/N)+1;
    reac2 = I2S(N*N-n+1)-(reac1-1)*N;
    if vsigma2s(I2S(N*N-n+1)) > theta
        fprintf(fid,'\n(%1.0f-%1.0f)\t%14.4f',reac1,reac2,vsigma2s(I2S(N*N-n+1)));
    end
end
fprintf(fid,'\n\nNOTES: delta = 0 implies no joint perturbation effects');
fprintf(fid,'\n       gamma = 0 implies no joint perturbation effects of order > 2');
fclose(fid);